<?php

/**
  * Manufacturers tab for admin panel, AdminManufacturers.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

include_once(realpath(dirname(__FILE__).'/../../').'/classes/AdminTab.php');

class AdminManufacturers extends AdminTab
{
	protected $maxImageSize = 200000;

	/** @var array countries list */
	private $countriesArray = array();

	public function __construct()
	{
		global $cookie;

		$this->table = 'manufacturer';
		$this->className = 'Manufacturer';
		$this->lang = false;
		$this->edit = true;
		
		$this->fieldImageSettings = array('name' => 'logo', 'dir' => 'm');
		
		$this->fieldsDisplay = array(
			'id_manufacturer' => array('title' => $this->l('ID'), 'align' => 'center', 'width' => 25),
			'name' => array('title' => $this->l('Name'), 'width' => 100),
			'logo' => array('title' => $this->l('Logo'), 'align' => 'center', 'image' => 'm', 'orderby' => false, 'search' => false)
		);

		$countries = Country::getCountries(intval($cookie->id_lang));
		foreach ($countries AS $country)
			$this->countriesArray[$country['id_country']] = $country['name'];

		parent::__construct();
	}

	public function postProcess()
	{
		parent::postProcess();
		
		/* Generate image with differents size */
		if (($id_manufacturer = intval(Tools::getValue('id_manufacturer'))) AND isset($_FILES) AND file_exists(_PS_MANU_IMG_DIR_.$id_manufacturer.'.jpg'))
		{
			$imagesTypes = ImageType::getImagesTypes('manufacturers');
			foreach ($imagesTypes AS $k => $imageType)
			{
				$file['tmp_name'] = _PS_MANU_IMG_DIR_.$id_manufacturer.'.jpg';
				$file['type'] = 'image/jpg';
				imageResize($file, _PS_MANU_IMG_DIR_.$id_manufacturer.'-'.stripslashes($imageType['name']).'.jpg', intval($imageType['width']), intval($imageType['height']));
			}
		}
	}

	public function displayForm()
	{
		global $currentIndex;
		
		$manufacturer = $this->loadObject(true);
		$address = new Address($manufacturer->id_address);
		$this->displayImage($manufacturer->id, _PS_MANU_IMG_DIR_.$manufacturer->id.'.jpg', 350);

		echo '
		<form action="'.$currentIndex.'&submitAdd'.$this->table.'=1" method="post" enctype="multipart/form-data">
		'.($manufacturer->id ? '<input type="hidden" name="id_'.$this->table.'" value="'.$manufacturer->id.'" />' : '').'
			<fieldset><legend><img src="../img/admin/manufacturers.gif" />'.$this->l('Manufacturers').'</legend>
				<label>'.$this->l('Name:').' </label>
				<div class="margin-form">
					<input type="text" size="40" name="name" value="'.Tools::getValue('name', $manufacturer->name).'" /> <sup>*</sup>
					<span class="hint" name="help_box">'.$this->l('Invalid characters:').' <>;=#{}<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Logo:').' </label>
				<div class="margin-form">
					<input type="file" name="logo" />
					<p>'.$this->l('Upload manufacturer logo from your computer').'</p>
				</div>
				<label>'.$this->l('Last name:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="address_name" value="'.$this->getFieldValue($address, 'name').'" style="text-transform: uppercase;" /> <sup>*</sup>
					<span class="hint" name="help_box">'.$this->l('Invalid characters:').' 0-9!<>,;?=+()@#"�{}_$%:<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('First name:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="surname" value="'.$this->getFieldValue($address, 'surname').'" /> <sup>*</sup>
					<span class="hint" name="help_box">'.$this->l('Invalid characters:').' 0-9!<>,;?=+()@#"�{}_$%:<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<label>'.$this->l('Address:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="address1" value="'.$this->getFieldValue($address, 'address1').'" /> <sup>*</sup>
				</div>
				<label>'.$this->l('Address').' (2):</label>
				<div class="margin-form">
					<input type="text" size="33" name="address2" value="'.$this->getFieldValue($address, 'address2').'" />
				</div>
				<label>'.$this->l('Post/Zip code:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="postcode" value="'.$this->getFieldValue($address, 'postcode').'" /> <sup>*</sup>
				</div>
				<label>'.$this->l('City:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="city" value="'.$this->getFieldValue($address, 'city').'" style="text-transform: uppercase;" /> <sup>*</sup>
				</div>
				<label>'.$this->l('Country:').'</label>
				<div class="margin-form">
					<select name="id_country" />';
		foreach ($this->countriesArray AS $id_country => $name)
			echo '		<option value="'.$id_country.'"'.(($this->getFieldValue($address, 'id_country') == $id_country) ? ' selected="selected"' : '').'>'.$name.'</option>';
		echo '		</select> <sup>*</sup>
				</div>
				<label>'.$this->l('Home phone:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="phone" value="'.$this->getFieldValue($address, 'phone').'" />
				</div>
				<label>'.$this->l('Mobile phone:').'</label>
				<div class="margin-form">
					<input type="text" size="33" name="phone_mobile" value="'.$this->getFieldValue($address, 'phone_mobile').'" />
				</div>
				<label>'.$this->l('Other:').'</label>
				<div class="margin-form">
					<textarea name="other" cols="36" rows="4">'.$this->getFieldValue($address, 'other').'</textarea>
					<span class="hint" name="help_box">'.$this->l('Forbidden characters:').' <>;=#{}<span class="hint-pointer">&nbsp;</span></span>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitAdd'.$this->table.'" class="button" />
				</div>
				<div class="small"><sup>*</sup> '.$this->l('Requireds fields').'</div>
			</fieldset>
		</form>';
	}

}
