<?php

/**
  * Employee class, Employee.php
  * Employees management
  * @category classes
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */
  
class		Employee extends ObjectModel
{
	public 		$id;
	
	/** @var string Name */
	public 		$name;
	
	/** @var string Surname */
	public 		$surname;
	
	/** @var string e-mail */
	public 		$email;
	
	/** @var string Password */
	public 		$passwd;
	
	/** @var boolean Status */
	public 		$active = 1;
	
	/** @var string Determine employee profile */
	public 		$id_profile;
	
 	protected 	$fieldsRequired = array('name', 'surname', 'email', 'passwd', 'id_profile');
 	protected 	$fieldsSize = array('name' => 32, 'surname' => 32, 'email' => 128, 'passwd' => 32);
 	protected 	$fieldsValidate = array('name' => 'isName', 'surname' => 'isName', 'email' => 'isemail', 
		 'passwd' => 'isPasswd', 'active' => 'isBool', 'id_profile' => 'isInt');
	
	protected 	$table = 'employee';
	protected 	$identifier = 'id_employee';

	public	function getFields()
	{
	 	parent::validateFields();
		
		$fields['name'] = pSQL(strtoupper($this->name));
		$fields['surname'] = pSQL(ucfirst(strtolower($this->surname)));
		$fields['email'] = pSQL($this->email);
		$fields['passwd'] = pSQL($this->passwd);
		$fields['active'] = intval($this->active);
		$fields['id_profile'] = intval($this->id_profile);
		
		return $fields;
	}
	
	/**
	  * Return employee instance from its e-mail (optionnaly check password)
	  * 
	  * @param string $email e-mail
	  * @param string $passwd Password is also checked if specified
	  * @return Employee instance
	  */
	public function getByemail($email, $passwd = null)
	{
	 	if (!Validate::isemail($email) OR ($passwd != null AND !Validate::isPasswd($passwd)))
	 		die(Tools::displayError());

		$result = Db::getInstance()->getRow('
		SELECT * 
		FROM `'._DB_PREFIX_.'employee`
		WHERE `active` = 1
		AND `email` = \''.pSQL($email).'\'
		'.($passwd ? 'AND `passwd` = \''.Tools::encrypt($passwd).'\'' : ''));
		if (!$result)
			return false;
		$this->id = $result['id_employee'];
		$this->id_profile = $result['id_profile'];
		foreach ($result AS $key => $value)
			if (key_exists($key, $this))
				$this->{$key} = $value;
		return $this;
	}
	
	static public function employeeExists($email)
	{
	 	if (!Validate::isemail($email))
	 		die (Tools::displayError());
	 	
		$result = Db::getInstance()->getRow('
		SELECT `id_employee`
		FROM `'._DB_PREFIX_.'employee`
		WHERE `email` = \''.pSQL($email).'\'');
		return isset($result['id_employee']);
	}

	/**
	  * Check if employee password is the right one
	  * 
	  * @param string $passwd Password
	  * @return boolean result
	  */
	static public function checkPassword($id_employee, $passwd)
	{
	 	if (!Validate::isUnsignedId($id_employee) OR !Validate::isMd5($passwd))
	 		die (Tools::displayError());
		
		$result = Db::getInstance()->getRow('
		SELECT `id_employee`
		FROM `'._DB_PREFIX_.'employee`
		WHERE `id_employee` = '.intval($id_employee).' AND `passwd` = \''.pSQL($passwd).'\'');
			
		return isset($result['id_employee']) ? $result['id_employee'] : false;
	}
}

?>